## Load gemtc package, which enables you to run node splits
library(gemtc)

## Load data from .csv file
data<-read.csv("O:/Documents/data.csv",
               header=TRUE,stringsAsFactors = FALSE)

## Get R to restructure data into necessary format for node-splitting
ns.data<-mtc.data.studyrow(data,
                  armVars=c('treatment'='t', 'responders'='r', 'sampleSize'='n'),
                  nArmsVar='na',
                  studyVars=c(),
                  studyNames=data$studyid,
                  treatmentNames=NA,
                  patterns=c('%s..', '%s..%d.'))
net<-mtc.network(data.ab=ns.data,description="Outcome")

## Plot network
plot(net)

## Print which nodes to split
splitcomps<-mtc.nodesplit.comparisons(net)
print(splitcomps)

## Run node split model
RP.split<-mtc.nodesplit(net,comparisons=splitcomps,
                        n.adapt=40000,            #adaption phase
                        n.iter=50000,             #burn-in and post-burn-in samples
                        thin=1,                   #thinning rate
                        n.chain=3,                #number of chains
                        likelihood="binom",       #likelihood
                        link="logit",           #link function
                        linearModel="fixed")

## Save node-split object in case you want to load it later, instead of re-running model
#setwd("O:/Documents/")
#save(RP.split,"RP.split",file="filename.RData")

## Load saved node-split object
#load("O:/Documents/filename.RData")

## Visually inspect history plots to check convergence - takes a long time, depends on number of nodes to split
#plot(RP.split)          #hit Esc key if you want R to stop creating plots

## Summarize and plot results
sum.RP.split<-summary(RP.split)
plot(sum.RP.split)
## Replace "Study" in plot with "Comparison"
#text(x=0.09, y = 1.165, labels = "Comparison")

## Get model fit statistics and between-study SD
fitall2RE<-lapply(RP.split,summary)
## Create table with model fit statistics and between-study SD
fitstats2RE<-data.frame(sdMed=rep(0,length(fitall2RE)),
                        sdlower=rep(0,length(fitall2RE)),
                        sdupper=rep(0,length(fitall2RE)),
                        Dbar=rep(0,length(fitall2RE)),
                        pD=rep(0,length(fitall2RE)),
                        DIC=rep(0,length(fitall2RE)),row.names=names(fitall2RE),
                        nodatapts=rep(0,length(fitall2RE)))
for(i in 1:length(fitall2RE)){
  fitstats2RE[i,]<-c(fitall2RE[[i]]$summaries$quantiles["sd.d","50%"],
                     fitall2RE[[i]]$summaries$quantiles["sd.d","2.5%"],
                     fitall2RE[[i]]$summaries$quantiles["sd.d","97.5%"],
                     fitall2RE[[i]]$DIC[1:4])
}

fitstats2RE

## Create table with direct and indirect estimates
estsRE<-data.frame(dirMed=rep(0,(length(fitall2RE)-1)),
                        dirlower=rep(0,(length(fitall2RE)-1)),
                        dirupper=rep(0,(length(fitall2RE)-1)),
                        indirMed=rep(0,(length(fitall2RE)-1)),
                        indirlower=rep(0,(length(fitall2RE)-1)),
                        indirupper=rep(0,(length(fitall2RE)-1)),row.names=names(fitall2RE)[1:(length(fitall2RE)-1)])
for(i in 1:(length(fitall2RE)-1)){
  estsRE[i,]<-c(fitall2RE[[i]]$summaries$quantiles["d.direct","50%"],
                     fitall2RE[[i]]$summaries$quantiles["d.direct","2.5%"],
                     fitall2RE[[i]]$summaries$quantiles["d.direct","97.5%"],
                     fitall2RE[[i]]$summaries$quantiles["d.indirect","50%"],
                     fitall2RE[[i]]$summaries$quantiles["d.indirect","2.5%"],
                     fitall2RE[[i]]$summaries$quantiles["d.indirect","97.5%"])
}

estsRE
