###################
## DEV-DEV PLOTS ##
###################

## You will need the deviance for each study arm in the NMA model
## and its deviance in the UME model
## These deviance estimates can be loaded in different files 
## but the studies should be in the same order.

## UME is a vector of study arms' deviance in the UME model
## NMA is a vector of study arms' deviance in the NMA model
## node is the name or ID of the study arm
## We would normally set the threshold of deviance to 1.5
## but this assumption can be relaxed



#####################################
## FUNCTIONS TO MAKE DEV-DEV PLOTS ##
#####################################

## There's a choice between the baseR version (no labels)
## and the ggplot version (which calls for the install of ggplot2 and ggrepel)

## Dev-dev plot for a single outcome: baseR version
devdevBase <- function(UME, NMA, threshold = 1.5, node) {
  df<- data.frame(UME, node, NMA)
  maxdev <- max(max(df$UME), max(df$NMA))
  df$deviant <- rep(0)
  df$ratio <- df$NMA/df$UME
  df$deviant <- ifelse(df$ratio > threshold & df$NMA > 2, 1, 0)
  (df$node[df$deviant==1])
  
  ## needs a sequence based on the dev threshold
  df$index <- seq(0, maxdev, length=dim(df)[1])
  df$index2 <- threshold*df$index  
  df$index2 <- ifelse(df$index2 < 2, 2, df$index2)
  
  plot(df$UME~df$NMA, xlim=c(0,maxdev), ylim=c(0,maxdev))
  points(UME~NMA, data = df[df$deviant == 1,], col="orange")
  abline(a=0,b=1,col=2)
  lines(df$index ~ df$index2, col="grey")
  
} 

## Dev-dev plot for a single outcome: ggplot version
devdevGG <- function(UME, NMA, node, threshold = 1.5) {
  
  require(ggplot2)  
  require(ggrepel)

  df<- data.frame(UME, node, NMA)
  maxdev <- max(max(df$UME), max(df$NMA))
  df$deviant <- rep(0)
  df$ratio <- df$NMA/df$UME
  df$deviant <- ifelse(df$ratio > threshold & df$NMA > 2, 1, 0)
  (df$node[df$deviant==1])
  ## needs a sequence based on the devth
  df$index <- seq(0, maxdev, length=dim(df)[1])
  df$index2 <- threshold*df$index  
  df$index2 <- ifelse(df$index2 < 2, 2, df$index2)
  
  ggplot(df, aes(x=NMA, y=UME, label=node)) + 
    geom_abline(slope=1, intercept = 0, col="red", lwd=1.2) +
    geom_point() +
    ylim(c(0, maxdev)) +
    xlim(c(0, maxdev)) +
    geom_line(aes(y=index, x=index2), col="grey", lty=2, lwd = 1.2) + 
    ggrepel::geom_label_repel(data=df[df$deviant==1,]) + 
    xlab("Standard NMA") +
    ylab("Inconsistency NMA") +
    theme_bw() + geom_point(data=df[df$deviant==1,], col="orange", size=1.5) 
} 



##############
## TOY DATA ##
##############

## Here node (study arms) are represented with single letters
## We would advise using informative names
testdf <- data.frame(node_name = sample(letters, 20),
                     UME_dev = rnorm(20, 1, 0.2),
                     NMA_dev = rnorm(20, 2, 0.5))

## These functions would allow separate columns from different files to be be used 
## (remembering that studies need to be in the same order to be compared in a
## dev-dev plot)

devdevBase(UME = testdf$UME_dev, 
           NMA = testdf$NMA_dev, 
           node = testdf$node_name, 
           threshold = 1.5)

devdevGG(UME = testdf$UME_dev, 
         NMA = testdf$NMA_dev, 
         node = testdf$node_name, 
         threshold = 2)